==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sv.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Viktigt",
    "Today" : "Idag",
    "Week" : "Vecka",
    "All" : "Alla",
    "Current" : "Nuvarande",
    "Completed" : "Slutförande",
    "Tasks" : "Uppgifter",
    "The Tasks app for Nextcloud" : "En uppgift-app för Nextcloud",
    "Default list" : "Standardlista",
    "Visibility of Smart Collections" : "Synlighet av smarta samlingar",
    "Hidden" : "Gömd",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "Can edit" : "Kan ändra",
    "Unshare with {displayName}" : "Sluta dela med {displayName}",
    "Unable to delete the share." : "Kan inte ta bort delningen.",
    "Unable to change permissions." : "Kan inte ändra behörigheter.",
    "Edit" : "Ändra",
    "Copy private link" : "Kopiera privat länk",
    "Copied" : "Kopierad",
    "Cannot copy" : "Kan inte kopieria",
    "Export" : "Exportera",
    "Delete" : "Ta bort",
    "Unshare" : "Sluta dela",
    "Save" : "Spara",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Detta kommer att radera kalender \"{calendar}\" och alla dess händelser och uppgifter.",
    "This will unshare the calendar \"{calendar}\"." : "Detta kommer att avsluta delning av kalender \"{calendar}\".",
    "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
    "Calendar link could not be copied to clipboard." : "Kalenderlänk kunde inte kopieras till urklipp.",
    "The name \"{calendar}\" is already used." : "Namnet \"{calendar}\" används redan.",
    "An empty name is not allowed." : "Ett tomt namn är inte tillåtet.",
    "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delad med {num} enhet","Delad med {num} enheter"],
    "Trash bin" : "Papperskorg",
    "Name" : "Namn",
    "Deleted" : "Borttagen",
    "Restore" : "Återställ",
    "Delete permanently" : "Ta bort permanent",
    "Empty trash bin" : "Töm papperskorgen",
    "Untitled task" : "Namnlös uppgift",
    "Untitled event" : "Namnlös händelse",
    "Unknown calendar" : "Okänd kalender",
    "Could not load deleted calendars and objects" : "Kunde inte ladda borttagna kalendrar och objekt",
    "Could not restore calendar or event" : "Kunde inte återställa kalender eller händelse",
    "Do you really want to empty the trash bin?" : "Vill du verkligen tömma papperskorgen?",
    "Select a calendar" : "Välj en kalender",
    "Delete all completed tasks." : "Ta bort alla slutförda uppgifter.",
    "Delete completed tasks." : "Ta bort slutförda uppgifter.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Ta bort alla slutförda uppgifter från kalender \"{calendar}\".",
    "No errors" : "Inga fel",
    "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Detta kommer att radera {taskCount} slutförd uppgift och dess underuppgifter från kalender \"{calendar}\".","Detta kommer att radera {taskCount} slutförda uppgifter och deras underuppgifter från kalender \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kunde inte radera {failedCount} uppgift.","Kunde inte radera {failedCount} uppgifter."],
    "Add an important task to \"{calendar}\"…" : "Lägg till en viktig uppgift till \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Lägg till en uppgift som förfaller idag i \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Lägg till en aktuell uppgift i \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Lägg till en uppgift i \"{calendar}\"…",
    "Load all completed tasks." : "Läs in alla slutförda uppgifter.",
    "Change sort order" : "Ändra sorteringsordning",
    "Relevance" : "Relevans",
    "Sort by completed state, due date, priority, start date and summary." : "Sortera efter slutförd status, förfallodag, prioritet, startdatum och sammanfattning.",
    "Start date" : "Startdatum",
    "Sort by start date and summary." : "Sortera efter startdatum och sammanfattning.",
    "Due date" : "Slutdatum",
    "Sort by due date and summary." : "Sortera efter förfallodatum och sammanfattning.",
    "Created date" : "Skapad datum",
    "Sort by created date and summary." : "Sortera efter skapat datum och sammanfattning.",
    "Last modified" : "Senast ändrad",
    "Sort by last-modified date and summary." : "Sortera efter senast ändrat datum och sammanfattning.",
    "Completed date" : "Slutförd datum",
    "Sort by completed date." : "Sortera efter slutförd datum.",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Sortera efter prioritering och sammanfattning.",
    "Alphabetically" : "Alfabetisk",
    "Sort by summary and priority." : "Sortera efter sammanfattning och prioritering.",
    "Manually" : "Manuellt",
    "Sort by manual order." : "Sortera efter manuell ordning.",
    "{complete} % completed" : "{complete} % slutfört",
    "Add subtask" : "Lägg till underuppgift",
    "Show subtasks" : "Visa underuppgifter",
    "Hide subtasks" : "Dölj underuppgifter",
    "Delete task" : "Ta bort uppgift",
    "[Yesterday]" : "[Igår]",
    "[Today]" : "[Idag]",
    "[Tomorrow]" : "[Imorgon]",
    "Add a subtask to \"{task}\"…" : "Lägg till en underuppgift till \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Raderar uppgiften om {countdown} sekund","Raderar uppgiften om {countdown} sekunder"],
    "Task is completed" : "Uppgift genomförd",
    "Cancel" : "Avbryt",
    "Close" : "Stäng",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n slutförda uppgifter","%n slutförda uppgifter"],
    "Tomorrow" : "Imorgon",
    "Add List…" : "Lägg till lista...",
    "New List" : "Ny lista",
    "All day" : "Hela dagen",
    "Edit title" : "Redigera titel",
    "Details" : "Detaljer",
    "Select a classification" : "Välj en klassificering",
    "Select a status" : "Välj en status",
    "Select tags" : "Välj taggar",
    "Notes" : "Anteckning",
    "Reminders" : "Påminnelser",
    "Repeat" : "Upprepa",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "Needs action" : "Behöver handling",
    "In process" : "Pågående",
    "Canceled" : "Avbruten",
    "Loading task from server." : "Läser in uppgiften från servern.",
    "Task not found!" : "Uppgift hittades inte!",
    "[Starts today]" : "[Startar idag]",
    "[Starts tomorrow]" : "[Startar imorgon]",
    "[Starts on] LL" : "[Startar kl] LL",
    "[Started yesterday]" : "[Startade igår]",
    "[Started on] LL" : "[Startade kl] LL",
    "[Started today at] LT" : "[Startade idag kl] LT",
    "[Starts today at] LT" : "[Startar idag kl] LT",
    "[Starts tomorrow at] LT" : "[Startar imorgon kl] LT",
    "[Starts on] LL [at] LT" : "[Startar på] LL [kl] LT",
    "[Started yesterday at] LT" : "[Startade igår kl] LT",
    "[Started on] LL [at] LT" : "[Startade på] LL [kl] LT",
    "Set start date" : "Sätt startdatum",
    "[Due today]" : "[Förfaller idag]",
    "[Due tomorrow]" : "[Förfaller imorgon]",
    "[Due on] LL" : "[Förfaller på] LL",
    "[Was due yesterday]" : "[Förföll igår]",
    "[Was due on] LL" : "[Förföll] LL",
    "[Was due today at] LT" : "[Förföll idag kl] LT",
    "[Due today at] LT" : "[Förfaller idag kl] LT",
    "[Due tomorrow at] LT" : "[Förfaller imorgon kl] LT",
    "[Due on] LL [at] LT" : "[Förfaller på] LL [kl] LT",
    "[Was due yesterday at] LT" : "[Förföll igår kl] LT",
    "[Was due on] LL [at] LT" : "[Förföll] LL [kl] LT",
    "Set due date" : "Sätt slutdatum",
    "Priority {priority}: low" : "Prioritet {priority}: låg",
    "Priority {priority}: medium" : "Prioritet {priority}: medium",
    "Priority {priority}: high" : "Prioritet {priority}: hög",
    "No priority assigned" : "Ingen prioritet tilldelad",
    "{percent} % completed" : "{percent} % slutfört",
    "Successfully created the task." : "Uppgiften skapad.",
    "Could not delete the task." : "Kunde inte radera uppgiften.",
    "Synchronizing to the server." : "Synkroniserar till servern.",
    "Task successfully saved to server." : "Uppgiften sparades i servern.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Det gick inte att uppdatera uppgiften eftersom den ändrades på servern. Klicka för att uppdatera, lokala ändringar kommer att ignoreras.",
    "Could not update the task." : "Kunde inte uppdatera uppgiften.",
    "Successfully updated the task." : "Uppgiften uppdaterad.",
    "Task successfully moved to new calendar." : "Uppgiften flyttad till en ny kalender.",
    "An error occurred" : "Ett fel uppstod",
    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sv.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Kommande uppgifter",
    "Important" : "Viktigt",
    "Today" : "Idag",
    "Week" : "Vecka",
    "All" : "Alla",
    "Current" : "Nuvarande",
    "Completed" : "Slutförande",
    "Tasks" : "Uppgifter",
    "The Tasks app for Nextcloud" : "En uppgift-app för Nextcloud",
    "Default list" : "Standardlista",
    "Visibility of Smart Collections" : "Synlighet av smarta samlingar",
    "Hidden" : "Gömd",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Tasks settings" : "Uppgiftinställningar",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "Can edit" : "Kan ändra",
    "Unshare with {displayName}" : "Sluta dela med {displayName}",
    "Unable to delete the share." : "Kan inte ta bort delningen.",
    "Unable to change permissions." : "Kan inte ändra behörigheter.",
    "Edit" : "Ändra",
    "Copy private link" : "Kopiera privat länk",
    "Copied" : "Kopierad",
    "Cannot copy" : "Kan inte kopieria",
    "Export" : "Exportera",
    "Delete" : "Ta bort",
    "Unshare" : "Sluta dela",
    "List name" : "Namn på lista",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Detta kommer att radera kalender \"{calendar}\" och alla dess händelser och uppgifter.",
    "This will unshare the calendar \"{calendar}\"." : "Detta kommer att avsluta delning av kalender \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Det här kommer att radera listan \"{list}\" och alla motsvarande uppgifter.",
    "This will unshare the list \"{list}\"." : "Det här kommer att ta bort delning av listan \"{list}\".",
    "Share this calendar" : "Dela denna kalender",
    "Share this list" : "Dela den här listan",
    "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
    "List link copied to clipboard." : "Listlänk kopierad till urklipp.",
    "Calendar link could not be copied to clipboard." : "Kalenderlänk kunde inte kopieras till urklipp.",
    "List link could not be copied to clipboard." : "Listlänken kunde inte kopieras till urklipp.",
    "The name \"{calendar}\" is already used." : "Namnet \"{calendar}\" används redan.",
    "An empty name is not allowed." : "Ett tomt namn är inte tillåtet.",
    "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delad med {num} enhet","Delad med {num} enheter"],
    "Trash bin" : "Papperskorg",
    "Name" : "Namn",
    "Deleted" : "Borttagen",
    "Restore" : "Återställ",
    "Delete permanently" : "Ta bort permanent",
    "Empty trash bin" : "Töm papperskorgen",
    "Untitled task" : "Namnlös uppgift",
    "Untitled event" : "Namnlös händelse",
    "Untitled item" : "Namnlöst objekt",
    "Unknown calendar" : "Okänd kalender",
    "Could not load deleted calendars and objects" : "Kunde inte ladda borttagna kalendrar och objekt",
    "Could not delete calendar or event" : "Det gick inte att ta bort kalender eller händelse",
    "Could not restore calendar or event" : "Kunde inte återställa kalender eller händelse",
    "Do you really want to empty the trash bin?" : "Vill du verkligen tömma papperskorgen?",
    "Select a calendar" : "Välj en kalender",
    "No calendar matches the search." : "Ingen kalender matchar sökningen.",
    "Set date" : "Ange datum",
    "Set time" : "Ange tid",
    "Delete date" : "Ta bort datum",
    "Click here to add a note." : "Klicka här för att lägga till en anteckning.",
    "Set value" : "Ange ett värde",
    "Delete value" : "Ta bort värde",
    "Add this as a new tag" : "Lägg till som en ny tagg",
    "No tag available. Create one!" : "Ingen tagg tillgänglig. Skapa en!",
    "Delete all completed tasks." : "Ta bort alla slutförda uppgifter.",
    "Delete completed tasks." : "Ta bort slutförda uppgifter.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Ta bort alla slutförda uppgifter från kalender \"{calendar}\".",
    "No errors" : "Inga fel",
    "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Detta kommer att radera {taskCount} slutförd uppgift och dess underuppgifter från kalender \"{calendar}\".","Detta kommer att radera {taskCount} slutförda uppgifter och deras underuppgifter från kalender \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kunde inte radera {failedCount} uppgift.","Kunde inte radera {failedCount} uppgifter."],
    "Add an important task to \"{calendar}\"…" : "Lägg till en viktig uppgift till \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Lägg till en uppgift som förfaller idag i \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Lägg till en aktuell uppgift i \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Lägg till en uppgift i \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Hämta slutförda uppgifter för alla listor.",
    "Change sort order" : "Ändra sorteringsordning",
    "Relevance" : "Relevans",
    "Sort by completed state, due date, priority, start date and summary." : "Sortera efter slutförd status, förfallodag, prioritet, startdatum och sammanfattning.",
    "Start date" : "Startdatum",
    "Due date" : "Slutdatum",
    "Created date" : "Skapad datum",
    "Last modified" : "Senast ändrad",
    "Completed date" : "Slutförd datum",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Sortera efter prioritering och sammanfattning.",
    "Alphabetically" : "Alfabetisk",
    "Sort by summary and priority." : "Sortera efter sammanfattning och prioritering.",
    "Manually" : "Manuellt",
    "Sort by manual order." : "Sortera efter manuell ordning.",
    "{complete} % completed" : "{complete} % slutfört",
    "Add subtask" : "Lägg till underuppgift",
    "Show subtasks" : "Visa underuppgifter",
    "Hide subtasks" : "Dölj underuppgifter",
    "Delete task" : "Ta bort uppgift",
    "[Yesterday]" : "[Igår]",
    "[Today]" : "[Idag]",
    "[Tomorrow]" : "[Imorgon]",
    "Add a subtask to \"{task}\"…" : "Lägg till en underuppgift till \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Raderar uppgiften om {countdown} sekund","Raderar uppgiften om {countdown} sekunder"],
    "Task is completed" : "Uppgift genomförd",
    "Create a new task" : "Skapa ny uppgift",
    "Cancel" : "Avbryt",
    "Create task" : "Skapa uppgift",
    "Close" : "Stäng",
    "Open task" : "Öppna uppgift",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n slutförda uppgifter","%n slutförda uppgifter"],
    "Tomorrow" : "Imorgon",
    "Add List…" : "Lägg till lista...",
    "All day" : "Hela dagen",
    "Show in Calendar" : "Visa i kalender",
    "Edit title" : "Redigera titel",
    "Details" : "Detaljer",
    "Select a classification" : "Välj en klassificering",
    "Select a status" : "Välj en status",
    "Select tags" : "Välj taggar",
    "Notes" : "Anteckning",
    "Reminders" : "Påminnelser",
    "Repeat" : "Upprepa",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "Needs action" : "Behöver handling",
    "In process" : "Pågående",
    "Canceled" : "Avbruten",
    "Clear status" : "Rensa status",
    "Loading task from server." : "Läser in uppgiften från servern.",
    "Task not found!" : "Uppgift hittades inte!",
    "[Starts today]" : "[Startar idag]",
    "[Starts tomorrow]" : "[Startar imorgon]",
    "[Starts on] LL" : "[Startar kl] LL",
    "[Started yesterday]" : "[Startade igår]",
    "[Started on] LL" : "[Startade kl] LL",
    "[Started today at] LT" : "[Startade idag kl] LT",
    "[Starts today at] LT" : "[Startar idag kl] LT",
    "[Starts tomorrow at] LT" : "[Startar imorgon kl] LT",
    "[Starts on] LL [at] LT" : "[Startar på] LL [kl] LT",
    "[Started yesterday at] LT" : "[Startade igår kl] LT",
    "[Started on] LL [at] LT" : "[Startade på] LL [kl] LT",
    "Set start date" : "Sätt startdatum",
    "[Due today]" : "[Förfaller idag]",
    "[Due tomorrow]" : "[Förfaller imorgon]",
    "[Due on] LL" : "[Förfaller på] LL",
    "[Was due yesterday]" : "[Förföll igår]",
    "[Was due on] LL" : "[Förföll] LL",
    "[Was due today at] LT" : "[Förföll idag kl] LT",
    "[Due today at] LT" : "[Förfaller idag kl] LT",
    "[Due tomorrow at] LT" : "[Förfaller imorgon kl] LT",
    "[Due on] LL [at] LT" : "[Förfaller på] LL [kl] LT",
    "[Was due yesterday at] LT" : "[Förföll igår kl] LT",
    "[Was due on] LL [at] LT" : "[Förföll] LL [kl] LT",
    "Set due date" : "Sätt slutdatum",
    "Priority {priority}: low" : "Prioritet {priority}: låg",
    "Priority {priority}: medium" : "Prioritet {priority}: medium",
    "Priority {priority}: high" : "Prioritet {priority}: hög",
    "No priority assigned" : "Ingen prioritet tilldelad",
    "{percent} % completed" : "{percent} % slutfört",
    "Successfully created the task." : "Uppgiften skapad.",
    "Could not delete the task." : "Kunde inte radera uppgiften.",
    "Synchronizing to the server." : "Synkroniserar till servern.",
    "Task successfully saved to server." : "Uppgiften sparades i servern.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Det gick inte att uppdatera uppgiften eftersom den ändrades på servern. Klicka för att uppdatera, lokala ändringar kommer att ignoreras.",
    "Could not update the task." : "Kunde inte uppdatera uppgiften.",
    "Successfully updated the task." : "Uppgiften uppdaterad.",
    "Task successfully moved to new calendar." : "Uppgiften flyttad till en ny kalender.",
    "An error occurred" : "Ett fel uppstod",
    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}"
},
"nplurals=2; plural=(n != 1);");
